@@ -66,10 +66,8 @@ class TestOWScoreDocuments(WidgetTest):
     def test_set_data(self):
         self.send_signal(self.widget.Inputs.corpus, self.corpus)
         self.assertEqual([x[0] for x in self.widget.model], self.corpus.titles.tolist())
-        self.assertTrue(self.widget.Warning.missing_words.is_shown())
 
         self.send_signal(self.widget.Inputs.words, self.words)
-        self.assertFalse(self.widget.Warning.missing_words.is_shown())
         self.wait_until_finished()
         self.assertEqual(len(self.widget.model), len(self.corpus))
         self.assertTrue(all(len(x) == 2 for x in self.widget.model))
@@ -137,17 +135,6 @@ class TestOWScoreDocuments(WidgetTest):
         self.send_signal(self.widget.Inputs.words, None)
         self.assertIsNone(self.widget.words)
 
-    def test_missing_corpus(self):
-        self.assertFalse(self.widget.Warning.missing_corpus.is_shown())
-        self.send_signal(self.widget.Inputs.words, self.words)
-        self.assertTrue(self.widget.Warning.missing_corpus.is_shown())
-        self.send_signal(self.widget.Inputs.corpus, self.corpus)
-        self.assertFalse(self.widget.Warning.missing_corpus.is_shown())
-        self.assertIsNotNone(self.get_output(self.widget.Outputs.corpus))
-        self.send_signal(self.widget.Inputs.corpus, None)
-        self.assertTrue(self.widget.Warning.missing_corpus.is_shown())
-        self.assertIsNone(self.get_output(self.widget.Outputs.corpus))
-
     @patch.object(DocumentEmbedder, "__call__", new=embedding_mock)
     def test_change_scorer(self):
         model = self.widget.model
@@ -434,6 +421,18 @@ class TestOWScoreDocuments(WidgetTest):
             [f"Document {i}" for i in range(1, 6)], output.titles.tolist()
         )
 
+    def test_output_unique(self):
+        corpus = Corpus.from_file("book-excerpts")
+        var = ContinuousVariable("Word count")
+        corpus = corpus.add_column(var, np.array([1 for _ in range(len(
+            corpus))]))
+        words = self.create_words_table(["doctor", "rum", "house"])
+        self.send_signal(self.widget.Inputs.corpus, corpus)
+        self.send_signal(self.widget.Inputs.words, words)
+        self.wait_until_finished()
+        output = self.get_output(self.widget.Outputs.selected_documents)
+        self.assertTrue("Word count (1)" in output.domain)
+
 
 if __name__ == "__main__":
     unittest.main()
