@@ -1,10 +1,13 @@
 import unittest
+from unittest import skipIf
 
 import numpy as np
+import gensim
 from AnyQt.QtCore import QItemSelectionModel
 
 from Orange.widgets.tests.base import WidgetTest
 from orangecontrib.text.corpus import Corpus
+from orangecontrib.text.topics import Topics
 from orangecontrib.text.widgets.owtopicmodeling import OWTopicModeling
 
 
@@ -21,7 +24,14 @@ class TestTopicModeling(WidgetTest):
         output = self.get_output(self.widget.Outputs.selected_topic)
         self.assertIsNone(output)
 
+    @skipIf(gensim.__version__ <= "4.1.2", "lsi model does not have random_seed")
     def test_saved_selection(self):
+        self.assertTrue(False)
+        # LSI does not have random_seed in gensim 4.1.2 but will have in next version
+        # when this test start to fail
+        # - remove line above
+        # - set random_seed to LSI model and set gensim requirement
+        # - remove skip on this test
         self.send_signal(self.widget.Inputs.corpus, self.corpus)
         self.wait_until_finished()
 
